#define PACKAGE "libpqxx"
#define PACKAGE_BUGREPORT "Jeroen T. Vermeulen <jtv@xs4all.nl>"
#define PACKAGE_NAME "libpqxx"
#define PACKAGE_STRING "libpqxx 3.0.2"
#define PACKAGE_TARNAME "libpqxx"
#define PACKAGE_VERSION "3.0.2"
#define VERSION "3.0.2"
